==> scala-k8s-objects_2.12-0.8.1-sources.jar: io/k8s/api/core/v1/PersistentVolumeClaimSpec.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** PersistentVolumeClaimSpec describes the common attributes of storage devices and allows a Source for provider-specific attributes */
final case class PersistentVolumeClaimSpec(
  accessModes : Option[Seq[String]] = None,
  volumeMode : Option[String] = None,
  dataSourceRef : Option[io.k8s.api.core.v1.TypedObjectReference] = None,
  storageClassName : Option[String] = None,
  dataSource : Option[io.k8s.api.core.v1.TypedLocalObjectReference] = None,
  volumeName : Option[String] = None,
  resources : Option[io.k8s.api.core.v1.ResourceRequirements] = None,
  selector : Option[io.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector] = None
) {

  /** Returns a new data with accessModes set to new value */
  def withAccessModes(value: Seq[String]) : PersistentVolumeClaimSpec = copy(accessModes = Some(value))
  /** Appends new values to accessModes */
  def addAccessModes(newValues: String*) : PersistentVolumeClaimSpec = copy(accessModes = Some(accessModes.fold(newValues)(_ ++ newValues)))
  /** if accessModes has a value, transforms to the result of function*/
  def mapAccessModes(f: Seq[String] => Seq[String]) : PersistentVolumeClaimSpec = copy(accessModes = accessModes.map(f))

  /** Returns a new data with volumeMode set to new value */
  def withVolumeMode(value: String) : PersistentVolumeClaimSpec = copy(volumeMode = Some(value))
  /** if volumeMode has a value, transforms to the result of function*/
  def mapVolumeMode(f: String => String) : PersistentVolumeClaimSpec = copy(volumeMode = volumeMode.map(f))

  /** Returns a new data with dataSourceRef set to new value */
  def withDataSourceRef(value: io.k8s.api.core.v1.TypedObjectReference) : PersistentVolumeClaimSpec = copy(dataSourceRef = Some(value))
  /** if dataSourceRef has a value, transforms to the result of function*/
  def mapDataSourceRef(f: io.k8s.api.core.v1.TypedObjectReference => io.k8s.api.core.v1.TypedObjectReference) : PersistentVolumeClaimSpec = copy(dataSourceRef = dataSourceRef.map(f))

  /** Returns a new data with storageClassName set to new value */
  def withStorageClassName(value: String) : PersistentVolumeClaimSpec = copy(storageClassName = Some(value))
  /** if storageClassName has a value, transforms to the result of function*/
  def mapStorageClassName(f: String => String) : PersistentVolumeClaimSpec = copy(storageClassName = storageClassName.map(f))

  /** Returns a new data with dataSource set to new value */
  def withDataSource(value: io.k8s.api.core.v1.TypedLocalObjectReference) : PersistentVolumeClaimSpec = copy(dataSource = Some(value))
  /** if dataSource has a value, transforms to the result of function*/
  def mapDataSource(f: io.k8s.api.core.v1.TypedLocalObjectReference => io.k8s.api.core.v1.TypedLocalObjectReference) : PersistentVolumeClaimSpec = copy(dataSource = dataSource.map(f))

  /** Returns a new data with volumeName set to new value */
  def withVolumeName(value: String) : PersistentVolumeClaimSpec = copy(volumeName = Some(value))
  /** if volumeName has a value, transforms to the result of function*/
  def mapVolumeName(f: String => String) : PersistentVolumeClaimSpec = copy(volumeName = volumeName.map(f))

  /** Returns a new data with resources set to new value */
  def withResources(value: io.k8s.api.core.v1.ResourceRequirements) : PersistentVolumeClaimSpec = copy(resources = Some(value))
  /** if resources has a value, transforms to the result of function*/
  def mapResources(f: io.k8s.api.core.v1.ResourceRequirements => io.k8s.api.core.v1.ResourceRequirements) : PersistentVolumeClaimSpec = copy(resources = resources.map(f))

  /** Returns a new data with selector set to new value */
  def withSelector(value: io.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector) : PersistentVolumeClaimSpec = copy(selector = Some(value))
  /** if selector has a value, transforms to the result of function*/
  def mapSelector(f: io.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector => io.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector) : PersistentVolumeClaimSpec = copy(selector = selector.map(f))
}

object PersistentVolumeClaimSpec {

    implicit val encoder : Encoder[io.k8s.api.core.v1.PersistentVolumeClaimSpec] = new Encoder[io.k8s.api.core.v1.PersistentVolumeClaimSpec] {
        def apply[T : Builder](o: io.k8s.api.core.v1.PersistentVolumeClaimSpec) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("accessModes", o.accessModes)
            .write("volumeMode", o.volumeMode)
            .write("dataSourceRef", o.dataSourceRef)
            .write("storageClassName", o.storageClassName)
            .write("dataSource", o.dataSource)
            .write("volumeName", o.volumeName)
            .write("resources", o.resources)
            .write("selector", o.selector)
            .build
        }
    }

    implicit val decoder: Decoder[PersistentVolumeClaimSpec] = new Decoder[PersistentVolumeClaimSpec] {
      def apply[T : Reader](t: T): Either[String, PersistentVolumeClaimSpec] = for {
          obj <- ObjectReader(t)
          accessModes <- obj.readOpt[Seq[String]]("accessModes")
          volumeMode <- obj.readOpt[String]("volumeMode")
          dataSourceRef <- obj.readOpt[io.k8s.api.core.v1.TypedObjectReference]("dataSourceRef")
          storageClassName <- obj.readOpt[String]("storageClassName")
          dataSource <- obj.readOpt[io.k8s.api.core.v1.TypedLocalObjectReference]("dataSource")
          volumeName <- obj.readOpt[String]("volumeName")
          resources <- obj.readOpt[io.k8s.api.core.v1.ResourceRequirements]("resources")
          selector <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector]("selector")
      } yield PersistentVolumeClaimSpec (
          accessModes = accessModes,
          volumeMode = volumeMode,
          dataSourceRef = dataSourceRef,
          storageClassName = storageClassName,
          dataSource = dataSource,
          volumeName = volumeName,
          resources = resources,
          selector = selector
        )
    }
}

==> scala-k8s-objects_2.13-0.18.0-sources.jar: io/k8s/api/core/v1/PersistentVolumeClaimSpec.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** PersistentVolumeClaimSpec describes the common attributes of storage devices and allows a Source for provider-specific attributes */
final case class PersistentVolumeClaimSpec(
  accessModes : Option[Seq[String]] = None,
  volumeMode : Option[String] = None,
  dataSourceRef : Option[io.k8s.api.core.v1.TypedObjectReference] = None,
  storageClassName : Option[String] = None,
  dataSource : Option[io.k8s.api.core.v1.TypedLocalObjectReference] = None,
  volumeName : Option[String] = None,
  volumeAttributesClassName : Option[String] = None,
  resources : Option[io.k8s.api.core.v1.VolumeResourceRequirements] = None,
  selector : Option[io.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector] = None
) {

  /** Returns a new data with accessModes set to new value */
  def withAccessModes(value: Seq[String]) : PersistentVolumeClaimSpec = copy(accessModes = Some(value))
  /** Appends new values to accessModes */
  def addAccessModes(newValues: String*) : PersistentVolumeClaimSpec = copy(accessModes = Some(accessModes.fold(newValues)(_ ++ newValues)))
  /** if accessModes has a value, transforms to the result of function*/
  def mapAccessModes(f: Seq[String] => Seq[String]) : PersistentVolumeClaimSpec = copy(accessModes = accessModes.map(f))

  /** Returns a new data with volumeMode set to new value */
  def withVolumeMode(value: String) : PersistentVolumeClaimSpec = copy(volumeMode = Some(value))
  /** if volumeMode has a value, transforms to the result of function*/
  def mapVolumeMode(f: String => String) : PersistentVolumeClaimSpec = copy(volumeMode = volumeMode.map(f))

  /** Returns a new data with dataSourceRef set to new value */
  def withDataSourceRef(value: io.k8s.api.core.v1.TypedObjectReference) : PersistentVolumeClaimSpec = copy(dataSourceRef = Some(value))
  /** if dataSourceRef has a value, transforms to the result of function*/
  def mapDataSourceRef(f: io.k8s.api.core.v1.TypedObjectReference => io.k8s.api.core.v1.TypedObjectReference) : PersistentVolumeClaimSpec = copy(dataSourceRef = dataSourceRef.map(f))

  /** Returns a new data with storageClassName set to new value */
  def withStorageClassName(value: String) : PersistentVolumeClaimSpec = copy(storageClassName = Some(value))
  /** if storageClassName has a value, transforms to the result of function*/
  def mapStorageClassName(f: String => String) : PersistentVolumeClaimSpec = copy(storageClassName = storageClassName.map(f))

  /** Returns a new data with dataSource set to new value */
  def withDataSource(value: io.k8s.api.core.v1.TypedLocalObjectReference) : PersistentVolumeClaimSpec = copy(dataSource = Some(value))
  /** if dataSource has a value, transforms to the result of function*/
  def mapDataSource(f: io.k8s.api.core.v1.TypedLocalObjectReference => io.k8s.api.core.v1.TypedLocalObjectReference) : PersistentVolumeClaimSpec = copy(dataSource = dataSource.map(f))

  /** Returns a new data with volumeName set to new value */
  def withVolumeName(value: String) : PersistentVolumeClaimSpec = copy(volumeName = Some(value))
  /** if volumeName has a value, transforms to the result of function*/
  def mapVolumeName(f: String => String) : PersistentVolumeClaimSpec = copy(volumeName = volumeName.map(f))

  /** Returns a new data with volumeAttributesClassName set to new value */
  def withVolumeAttributesClassName(value: String) : PersistentVolumeClaimSpec = copy(volumeAttributesClassName = Some(value))
  /** if volumeAttributesClassName has a value, transforms to the result of function*/
  def mapVolumeAttributesClassName(f: String => String) : PersistentVolumeClaimSpec = copy(volumeAttributesClassName = volumeAttributesClassName.map(f))

  /** Returns a new data with resources set to new value */
  def withResources(value: io.k8s.api.core.v1.VolumeResourceRequirements) : PersistentVolumeClaimSpec = copy(resources = Some(value))
  /** if resources has a value, transforms to the result of function*/
  def mapResources(f: io.k8s.api.core.v1.VolumeResourceRequirements => io.k8s.api.core.v1.VolumeResourceRequirements) : PersistentVolumeClaimSpec = copy(resources = resources.map(f))

  /** Returns a new data with selector set to new value */
  def withSelector(value: io.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector) : PersistentVolumeClaimSpec = copy(selector = Some(value))
  /** if selector has a value, transforms to the result of function*/
  def mapSelector(f: io.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector => io.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector) : PersistentVolumeClaimSpec = copy(selector = selector.map(f))
}

object PersistentVolumeClaimSpec {

    implicit val encoder : Encoder[io.k8s.api.core.v1.PersistentVolumeClaimSpec] = new Encoder[io.k8s.api.core.v1.PersistentVolumeClaimSpec] {
        def apply[T : Builder](o: io.k8s.api.core.v1.PersistentVolumeClaimSpec) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("accessModes", o.accessModes)
            .write("volumeMode", o.volumeMode)
            .write("dataSourceRef", o.dataSourceRef)
            .write("storageClassName", o.storageClassName)
            .write("dataSource", o.dataSource)
            .write("volumeName", o.volumeName)
            .write("volumeAttributesClassName", o.volumeAttributesClassName)
            .write("resources", o.resources)
            .write("selector", o.selector)
            .build
        }
    }

    implicit val decoder: Decoder[PersistentVolumeClaimSpec] = new Decoder[PersistentVolumeClaimSpec] {
      def apply[T : Reader](t: T): Either[String, PersistentVolumeClaimSpec] = for {
          obj <- ObjectReader(t)
          accessModes <- obj.readOpt[Seq[String]]("accessModes")
          volumeMode <- obj.readOpt[String]("volumeMode")
          dataSourceRef <- obj.readOpt[io.k8s.api.core.v1.TypedObjectReference]("dataSourceRef")
          storageClassName <- obj.readOpt[String]("storageClassName")
          dataSource <- obj.readOpt[io.k8s.api.core.v1.TypedLocalObjectReference]("dataSource")
          volumeName <- obj.readOpt[String]("volumeName")
          volumeAttributesClassName <- obj.readOpt[String]("volumeAttributesClassName")
          resources <- obj.readOpt[io.k8s.api.core.v1.VolumeResourceRequirements]("resources")
          selector <- obj.readOpt[io.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector]("selector")
      } yield PersistentVolumeClaimSpec (
          accessModes = accessModes,
          volumeMode = volumeMode,
          dataSourceRef = dataSourceRef,
          storageClassName = storageClassName,
          dataSource = dataSource,
          volumeName = volumeName,
          volumeAttributesClassName = volumeAttributesClassName,
          resources = resources,
          selector = selector
        )
    }
}
